@@ -112,11 +112,11 @@ class Engine(object):
         a fixed order although their computation order might be different due to the
         concurrent processing."""
         assert all(isinstance(arg, EnumeratedItem) for arg in enumerated_args)
-        new_enumeration, args = unpack(enumerated_args)
-        for arg in args:
-            if isinstance(arg, DelayedException):
+        for arg in enumerated_args:
+            if isinstance(arg.value, DelayedException):
                 callback(arg)
                 return
+        new_enumeration, args = unpack(enumerated_args)
         # dill can pickle more function types as pickle module (which underlies
         # multiprocessing) , eg lambdas or static methods, so we transport our computation job
         # serialized as strings, which we deserialize in the remote process again:
@@ -155,8 +155,8 @@ class DataStream(object):
     def get_all_in_order(self):
         results = [self.get() for _ in range(self.size())]
         for result in results:
-            if isinstance(result, DelayedException):
-                result.re_raise()
+            if isinstance(result.value, DelayedException):
+                result.value.re_raise()
         results.sort(key=lambda en_item: en_item.number)
         return [item.value for item in results]
 
@@ -278,7 +278,11 @@ class SummarizeComputation(Computation):
         items = []
         stream = self.input_streams[0]
         for i in range(stream.size()):
-            items.append(stream.get())
+            item = stream.get()
+            if isinstance(item.value, DelayedException):
+                self.put(item)
+                return
+            items.append(item)
         items.sort(key=lambda item: item.number)
         values = [v for __, v in items]
         arg = EnumeratedItem(0, values)
